@@ -5,8 +5,10 @@ from mysql_compare.mysql_compare import MysqlTableCompare
 parser = argparse.ArgumentParser(prog="ProgramName", description="What the program does", epilog="Text at the bottom of help")
 parser.add_argument("--source-dsn", type=str, required=True)
 parser.add_argument("--target-dsn", type=str, required=True)
-parser.add_argument("--database", type=str, required=True)
-parser.add_argument("--table", type=str, required=True)
+parser.add_argument("--src-database", type=str, required=True)
+parser.add_argument("--src-table", type=str, required=True)
+parser.add_argument("--dst-database", type=str, required=True)
+parser.add_argument("--dst-table", type=str, required=True)
 args = parser.parse_args()
 
 _userpass, _hostport = args.source_dsn.split("@")
@@ -19,7 +21,4 @@ _user, _pass = _userpass.split("/")
 _host, _port = _hostport.split(":")
 _target_dsn = {"host": _host, "port": _port, "user": _user, "password": _pass}
 
-_database = args.database
-_table = args.table
-
-MysqlTableCompare(_source_dsn, _target_dsn, _database, _table).run()
+MysqlTableCompare(_source_dsn, _target_dsn, args.src_database, args.src_table, args.dst_database, args.dst_table).run()
